# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## [Unreleased]

## [0.1.0] - 2025-08-07

### Added

- Add module `parser` with classes `Parser` and `BinaryParser`.

## [0.0.1] - 2025-08-03

### Added

- Add `SolidQueue` and subclass `BytesQueue`.

## [0.0.0] - 1970-01-01

### Added

- This is an example entry.
- See below for the other types of changes.

### Changed

- Change in functionality.

### Deprecated

- Feature that will be removed soon.

### Removed

- Feature that is now removed.

### Fixed

- Bug that was fixed.

### Security

- Security vulnerability notice.
